#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

/**/

#include "Common.h"

/**/

//----------------------------------------------------------
//Function for the event procedure
//----------------------------------------------------------
void BarBtnPush(WSCbase* object){
  //do something...
	MainWin->setProperty( WSNheight, 1 );
}
static WSCfunctionRegister  op("BarBtnPush",(void*)BarBtnPush);
